summaryrefslogtreecommitdiffstats
path: root/part/actions.h
diff options
context:
space:
mode:
Diffstat (limited to 'part/actions.h')
-rw-r--r--part/actions.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/part/actions.h b/part/actions.h
index 43d0967..3956c74 100644
--- a/part/actions.h
+++ b/part/actions.h
@@ -19,8 +19,8 @@
#define ACTIONS_H
#include <kaction.h>
-#include <qlabel.h>
-class QComboBox;
+#include <tqlabel.h>
+class TQComboBox;
/**
*@author Lumir Vanek
@@ -30,33 +30,33 @@ class KXmlEditorComboAction : public KAction
{
Q_OBJECT
public:
- KXmlEditorComboAction(const QString& text, int accel, const QObject *receiver, const char *member, QObject* parent, const char* name);
+ KXmlEditorComboAction(const TQString& text, int accel, const TQObject *receiver, const char *member, TQObject* parent, const char* name);
~KXmlEditorComboAction();
- virtual int plug(QWidget *w, int index = -1);
+ virtual int plug(TQWidget *w, int index = -1);
- virtual void unplug(QWidget *w);
+ virtual void unplug(TQWidget *w);
- /** Returns the text from the combobox' editline (@ref QComboBox::currentText). */
- QString currentText() const;
+ /** Returns the text from the combobox' editline (@ref TQComboBox::currentText). */
+ TQString currentText() const;
- /** Returns the current pixmap or 0, if there isn't any (see @ref QComboBox::pixmap). */
- const QPixmap * currentPixmap() const;
+ /** Returns the current pixmap or 0, if there isn't any (see @ref TQComboBox::pixmap). */
+ const TQPixmap * currentPixmap() const;
/**
* Inserts the given item as the first.
* Deletes the old entry, if the item was already in the list.
*/
- void insertItem( const QPixmap & pixmap, const QString & text );
+ void insertItem( const TQPixmap & pixmap, const TQString & text );
/** Tries to remove the item with the given text. */
- void removeItem( const QString & text );
+ void removeItem( const TQString & text );
/** returns combo box */
- QComboBox *comboBox();
+ TQComboBox *comboBox();
public slots:
/** Clears the whole combobox using @ref QComboBox::clear. */
void slotClear();
/** Clears the combobox' editline. */
void slotClearEdit();
@@ -68,20 +68,20 @@ protected:
* Tries to find an item with the given text. If it finds it,
* the items id is returned, otherwise -1.
*/
- virtual int findItem( const QString & text );
+ virtual int findItem( const TQString & text );
private:
- const QObject *m_receiver;
+ const TQObject *m_receiver;
const char *m_member;
- QComboBox * m_pCombo;
+ TQComboBox * m_pCombo;
};
-class ToolbarLabel : public QLabel
+class ToolbarLabel : public TQLabel
{
Q_OBJECT
public:
- ToolbarLabel( const QString & text );
+ ToolbarLabel( const TQString & text );
};
@@ -30,33 +30,33 @@ class KXmlEditorComboAction : public KAction
public slots:
- /** Clears the whole combobox using @ref QComboBox::clear. */
+ /** Clears the whole combobox using @ref TQComboBox::clear. */
void slotClear();
/** Clears the combobox' editline. */